import React from 'react'
import { useDrag, useDrop } from 'react-dnd'
import { Popover } from 'antd'
import { EditOutlined, CloseOutlined } from '@ant-design/icons'

import MkIcon from '@/components/mk-icon'
import './index.scss'

const Card = ({ id, card, moveCard, findCard, editCard, delCard }) => {
  const originalIndex = findCard(id).index

  const [{ isDragging }, drag] = useDrag({
    item: { type: 'chart', id, originalIndex },
    collect: monitor => ({
      isDragging: monitor.isDragging(),
    }),
  })

  const opacity = isDragging ? 0.5 : 1

  const edit = () => {
    editCard(id)
  }
  
  const del = () => {
    delCard(id)
  }

  const [, drop] = useDrop({
    accept: 'chart',
    canDrop: () => true,
    hover({ id: draggedId }) {
      if (!draggedId) return
      if (draggedId !== id) {
        const { index: overIndex } = findCard(id)
        moveCard(draggedId, overIndex)
      }
    }
  })

  return (
    <Popover overlayClassName="mk-popover-control-wrap" mouseLeaveDelay={0.2} mouseEnterDelay={0.2} content={
      <div className="mk-popover-control">
        <EditOutlined className="edit" title="编辑" onClick={edit} />
        {card.chartType !== 'table' ? <CloseOutlined className="edit close" title="删除" onClick={del} /> : null}
      </div>
    } trigger="hover">
      <div className="chart-tab" style={{ opacity: opacity}}>
        <div ref={node => drag(drop(node))}>
          <MkIcon type={card.icon} />
        </div>
      </div>
    </Popover>
  )
}
export default Card
